function [data, auxData, metaData, txtData, weights] = mydata_Perameles_nasuta

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Mammalia'; 
metaData.order      = 'Peramelemorphia'; 
metaData.family     = 'Peramelidae';
metaData.species    = 'Perameles_nasuta'; 
metaData.species_en = 'Greater long-nosed bandicoot'; 
metaData.ecoCode.climate = {'Cfa', 'Cfb'};
metaData.ecoCode.ecozone = {'TA'};
metaData.ecoCode.habitat = {'0iTf', '0iTh'};
metaData.ecoCode.embryo  = {'Tv'};
metaData.ecoCode.migrate = {};
metaData.ecoCode.food    = {'bxM', 'xiCi', 'xiHr', 'xiHl', 'xiF'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};
metaData.T_typical  = C2K(36.1); % K, body temp
metaData.data_0     = {'tg'; 'ax'; 'ap'; 'am'; 'Li'; 'Wwb'; 'Wwx'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-L'; 't-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2012 09 10];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.author_mod_1   = {'Bas Kooijman'};    
metaData.date_mod_1 = [2016 11 14];              
metaData.email_mod_1    = {'bas.kooijman@vu.nl'};            
metaData.address_mod_1  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'sta@akvaplan.niva.no'}; 
metaData.date_acc    = [2016 11 14]; 

%% set data
% zero-variate data

data.tg = 12;     units.tg = 'd';    label.tg = 'gestation time';             bibkey.tg = 'AnAge';   
  temp.tg = C2K(36.1);  units.temp.tg = 'K'; label.temp.tg = 'temperature';
data.tx = 66;     units.tx = 'd';    label.tx = 'time since birth at weaning'; bibkey.tx = 'AnAge';   
  temp.tx = C2K(36.1);  units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tp = 135;    units.tp = 'd';    label.tp = 'time since birth at puberty';   bibkey.tp = 'AnAge';
  temp.tp = C2K(36.1);  units.temp.tp = 'K'; label.temp.tp = 'temperature';
data.am = 5.6*365; units.am = 'd';    label.am = 'life span';                bibkey.am = 'AnAge';   
  temp.am = C2K(36.1);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Li  = 10;    units.Li  = 'cm';  label.Li  = 'ultimate lead length';   bibkey.Li  = 'Lyne1964';

data.Wwb = 0.245; units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'AnAge';
data.Wwx = 150;   units.Wwx = 'g';   label.Wwx = 'wet weight at weaning';   bibkey.Wwx = 'AnAge';
data.Wwi = 859;   units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';     bibkey.Wwi = 'AnAge';

data.Ri  = 6.9 * 2.7/ 365;   units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';     bibkey.Ri  = 'AnAge';   
  temp.Ri = C2K(36.1);  units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
 
% uni-variate data
% t-W data
data.tW = [ ... % time since birth (d), wet weight (g)
      0.000147661166 0.9934672045;
      0.01354515035 1.464252275;
      0.01908435429 1.492671066;
      0.02583980265 1.505253212;
      0.03536437974 1.685490464;
      0.01224998743 1.977718585;
      0.1001208599 3.141707699;
      0.1043289575 3.16691271;
      0.1054350402 3.293272681;
      0.09961103151 3.297851346;
      0.1094318081 3.308114911;
      0.1126384398 3.364720237;
      0.113462017 3.527544923;
      0.1189943231 3.545561937;
      0.1275782634 3.694769343;
      0.1297638855 3.753303281;
      0.1238284639 3.744032408;
      0.1288279489 3.883520478;
      0.1305932109 3.924796115;
      0.1345382452 3.861625017;
      0.1321208032 4.070148018;
      0.1354158553 4.105930291;
      0.1394734523 4.05834236;
      0.1424905974 4.137523866;
      0.1400891487 4.216005154;
      0.1359109416 4.235874511;
      0.1365690729 4.303369072;
      0.1404705227 4.328632578;
      0.1379129268 4.479965303;
      0.1441239561 4.442369684;
      0.1470974152 4.455673268;
      0.1478899522 4.571689957;
      0.1494967678 4.682349771;
      0.1565322191 4.346374892;
      0.1563783712 4.422693588;
      0.1610722565 4.409661258;
      0.1615454998 4.506666517;
      0.1630179096 4.568804203;
      0.1632752247 4.648512164;
      0.1585847883 4.666745383;
      0.1521165455 4.778945566;
      0.1670930559 5.010158291;
      0.1671539865 5.102040655;
      0.1672241143 5.207792056;
      0.1747007207 5.074593335;
      0.1849543002 4.812560077;
      0.1855447046 4.932083022;
      0.184621414 5.081370144;
      0.184047206 5.140430537;
      0.1844320289 5.25825885;
      0.1885287135 5.269614323;
      0.1848926262 5.336194184;
      0.1922258331 5.44922935;
      0.1992727808 5.130590767;
      0.2040448412 5.235445243;
      0.2037189544 5.668969612;
      0.2048469817 5.98258107;
      0.222662139 5.56132515;
      0.218746792 5.360945565;
      0.2134894518 6.065891056;
      0.2236789564 6.16971212;
      0.2341866052 6.290810985;
      0.2261783273 6.547214391;
      0.2037341028 6.000131847;
      0.2361480485 6.011287168;
      0.2376237041 5.770000692;
      0.2585781726 6.074628582;
      0.2714895694 6.120713418;
      0.2432977201 6.464191712;
      0.2527406731 6.521341268;
      0.2459980739 6.836454098;
      0.2639856764 6.675242606;
      0.2724316606 6.616414469;
      0.2587993088 7.024735551;
      0.279698087 6.474586598;
      0.2807810753 6.411961454;
      0.2804161009 6.786542419;
      0.2839914607 6.936705244;
      0.2909996256 7.022060832;
      0.3013016929 7.141465064;
      0.3015634033 6.919482493;
      0.2956519209 6.637992789;
      0.3029195985 6.652211072;
      0.3162445591 6.859464958;
      0.3220468263 6.976259858;
      0.3331309823 7.041765588;
      0.3213361165 7.291955915;
      0.3026790894 7.676961601;
      0.2848750221 7.498303715;
      0.322611297 7.82747195;
      0.3415716246 7.591519405;
      0.3396982969 7.387282594;
      0.3442531779 7.318793618;
      0.3540462617 7.13313755;
      0.3572713891 7.371793473;
      0.3626406503 7.452260146;
      0.3734720898 7.444992434;
      0.3486856575 7.990681435;
      0.3429605174 8.144352237;
      0.3586914237 8.125746827;
      0.3767006662 7.688849245;
      0.3803552492 7.804319981;
      0.3982556827 7.819977696;
      0.3954830035 7.492809176;
      0.4142151632 7.837739509;
      0.418078675 7.805793241;
      0.4279523348 7.895803764;
      0.4339751287 8.036830481;
      0.4212291778 8.08607577;
      0.4096422943 8.495740514;
      0.397432715 8.583028161;
      0.3776785992 8.546917862;
      0.4165862828 8.792637901;
      0.436137218 8.984833351;
      0.4468192049 8.752193801;
      0.4546766776 7.960059878;
      0.4706523545 8.156405029;
      0.4757517562 8.292406342;
      0.4887307782 8.132150269;
      0.4957207521 8.498392836;
      0.4837950311 8.859574448;
      0.476522958 9.147046697;
      0.4943822078 9.4089188;
      0.5133978194 9.410492997;
      0.5317942857 9.249203512;
      0.533315622 8.61432464;
      0.5274318323 8.52875457;
      0.5150889969 8.569253719;
      0.5069449605 8.466776317;
      0.4945883295 8.486471911;
      0.5506278487 8.359614144;
      0.5399661488 8.006208924;
      0.5493893549 7.725261728;
      0.5527875693 7.454133081;
      0.5274426176 7.465903188;
      0.5316588642 7.657556131;
      0.5127131772 7.453108284;
      0.5106184778 7.685843602;
      0.5022448191 7.699577873;
      0.4892196085 7.481863715;
      0.4888874656 7.13515731;
      0.4707860492 7.124739481;
      0.4706139087 7.327632629;
      0.478220627 7.698959094;
      0.4650508671 7.725745194;
      0.4536015335 7.726195378;
      0.4390764233 7.559048952;
      0.4492197394 7.284899785;
      0.4558372316 7.089446389;
      0.4518541577 6.941095188;
      0.4335162212 7.036487253;
      0.4342545223 6.762398305;
      0.4225491248 6.839186683;
      0.4118072552 6.827364973;
      0.4122978446 7.1046872;
      0.4182115248 7.235331638;
      0.4247225072 7.495900798;
      0.4066175403 7.325969554;
      0.3865096417 7.21883894;
      0.3957811975 6.863365173;
      0.393772416 6.76318513;
      0.403756136 6.556686511;
      0.415374466 6.811079865;
      0.4228385281 6.813123745;
      0.3688475196 6.329275962;
      0.3779140019 6.743670189;
      0.3782965255 6.858031242;
      0.3769022909 6.913780363;
      0.3719350972 6.977146444;
      0.3654507595 7.065075814;
      0.3459353615 6.772310353;
      0.3545397921 6.644098039;
      0.3545270445 6.47071559;
      0.3469675627 6.32478046;
      0.3704990694 6.353234802;
      0.3351587997 6.399854707;
      0.3386825275 6.626316728;
      0.335079678 6.588859321;
      0.3282655983 6.48786207;
      0.3274098313 6.276495757;
      0.3264529981 6.066882572;
      0.3199317705 5.945023272;
      0.3183527493 6.184595617;
      0.3181576161 6.352816175;
      0.3095484854 6.319781446;
      0.3072375531 6.07228189;
      0.3092702738 5.900243103;
      0.3027019112 5.707304992;
      0.2981047984 6.174587253;
      0.2993073488 6.292259578;
      0.2993740276 6.39281009;
      0.2899434159 5.891792883;
      0.2897790181 5.643883862;
      0.2904140551 5.522393307;
      0.2902325144 5.402792369;
      0.2790496929 5.496819551;
      0.2781174083 5.940862687;
      0.2765349382 6.175234144;
      0.2591844688 5.90979729;
      0.2580483941 5.584050426;
      0.2673741859 5.618682297;
      0.265010472 5.445748309;
      0.2716752008 5.475686248;
      0.2728199647 5.043739521;
      0.2492941046 4.869640801;
      0.2494194149 5.058606419;
      0.2506208156 5.174545114;
      0.2513191842 5.302716709;
      0.2510160869 5.462288617;
      0.241506455 5.304588549;
      0.2382586396 5.494197612;
      0.2383253184 5.594748124;
      0.2429376812 5.612940623;
      0.2429710206 5.663215879;
      0.2294594128 4.557863911;
      0.2290633982 4.885636879;
      0.2301040533 5.067492494;
      0.2172053025 5.040477583;
      0.2209517547 5.140326154;
      0.2265082032 5.194749389;
      0.2281919427 5.267249855;
      0.2187340444 5.187563115;
      0.2189971077 5.275939224;
      0.2031155992 5.067439167;
      0.2019968706 4.922009271;
      0.1956617823 4.926685427;
      0.2007609808 4.75406169;
      0.2086959869 4.84964357;
      0.214339706 4.881510122;
      0.2133553831 4.784602355;
      0.2149481999 4.565833564;
      0.2135307693 4.278285044;
      0.1916612607 4.443704733;
      0.1912476969 4.282535683;
      0.1893250365 4.158065327;
      0.1900518412 3.866640084;
      0.1734471801 4.26339121;
      0.1666871332 4.243874546;
      0.1720208572 4.42491123;
      0.1836288404 4.663701919;
      0.172310362 4.553160818;
      0.1553158731 4.207899013;
      0.1526914968 4.1043687;
      0.1525180035 3.996903169;
      0.1443407293 3.998463036;
      0.1328073707 3.718045741;
      0.135497073 3.611767885;
      0.1410305288 3.631518529;
      0.1460379597 3.628829481;
      0.1373015242 3.866299451;
      0.1288013041 3.535021949;
      0.1207215456 3.375315275;
      0.1204826247 3.323345386;
      0.1216781757 3.276303409;
      0.1261952204 3.304917184;
      0.1303929713 3.314519529;
      0.1193535494 3.162312824;
      0.1154026653 3.062503249;
      0.111852699 3.1047928;
      0.108468077 3.08809995;
      0.1126509842 3.229477636;
      0.1151696957 3.327826559;
      0.1044700579 2.917211565;
      0.106909343 2.741627525;
      0.09003211684 2.573195931;
      0.09061542032 2.373692048;
      0.08966988026 1.872790108;
      0.09510456899 1.897761138;
      0.07409522274 1.972856607;
      0.06505748138 1.601803118;
      0.06033350245 1.26113603;
      0.0485568276 1.230439379;
      0.04398503905 0.04015733983;
      0.03568600505 0.01226500367;
      0.03160541535 0.02518034393;
      0.02537714152 0.03677151983;
      0.01617310941 0.03159185245;
      0.01148037378 0.04635781226;
      0.005132639491 0.03196404376];
data.tW(:,1) = data.tW(:,1) * 365; % convert yr to d
data.tW(:,2) = data.tW(:,2).^3; % remove 1/3-root transformation
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(36.1);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW = 'Lyne1964';

data.tL = [ ... % time since birth (yr), headlength (mm)
      0.01164531038 10.58353149;
      0.05099853547 21.69938713;
      0.09000316827 36.56002257;
      0.1282133617 48.84144394;
      0.1480686995 52.98552184;
      0.1721540305 56.88082071;
      0.1864282756 60.81526594;
      0.2041794125 66.20142454;
      0.2230826237 71.35820319;
      0.2428778 69.27377973;
      0.264837154 72.15667109;
      0.2993249254 77.4839177;
      0.3399331023 79.10404635;
      0.395017133 85.61389353;
      0.4181045705 85.78364672;
      0.4754766944 90.17252657;
      0.4918477586 92.1006578;
      0.5734171337 92.05467528;
      0.648668001 95.12354824;
      0.7244589193 94.35209391;
      0.8780363583 100.2411708;
      0.9382312747 98.11468687;
      1.034095379 104.123897];
data.tL(:,1) = data.tL(:,1) * 365; % convert yr to d
data.tL(:,2) = data.tL(:,2)/ 10;   % convert mm to cm
units.tL  = {'d', 'cm'};  label.tL = {'time since birth', 'head length'};  
temp.tL   = C2K(36.1);  units.temp.tL = 'K'; label.temp.tL = 'temperature';
bibkey.tL = 'Lyne1964';

%% set weights for all real data
weights = setweights(data, []);

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);
data.psd.t_0 = 0;  units.psd.t_0 = 'd'; label.psd.t_0 = 'time at start development';
weights.psd.t_0 = 0.1;
weights.tW = 0 * weights.tW;

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;

%% Links
metaData.links.id_CoL = '76RLK'; % Cat of Life
metaData.links.id_ITIS = '552663'; % ITIS
metaData.links.id_EoL = '323870'; % Ency of Life
metaData.links.id_Wiki = 'Perameles_nasuta'; % Wikipedia
metaData.links.id_ADW = 'Perameles_nasuta'; % ADW
metaData.links.id_Taxo = '60062'; % Taxonomicon
metaData.links.id_WoRMS = ''; % WoRMS
metaData.links.id_MSW3 = '10900026'; % MSW3
metaData.links.id_AnAge = 'Perameles_nasuta'; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Perameles_nasuta}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Lyne1964'; type = 'Article'; bib = [ ... 
'author = {Lyne, A.G.}, ' ... 
'year = {1964}, ' ...
'title = {Observations on the breeding and growth of the marsupial \emph{Pelametes nasuta} {G}eoffroy, with notes on the other bandicoots}, ' ...
'journal = {Austral. J. Zool.}, ' ...
'volume = {12}, ' ...
'pages = {322--339}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Perameles_nasuta}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

